==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ko-KR/admin/settings/message.php <==
<?php

return [

    'update' => [
        'error'                 => '갱신 중 오류가 발생했습니다. ',
        'success'               => '설정이 갱신되었습니다.',
    ],
    'backup' => [
        'delete_confirm'        => '이 백업 파일을 지우시겠습니까? 이 동작은 되돌리기가 되지 않습니다. ',
        'file_deleted'          => '백업 파일이 삭제 되었습니다. ',
        'generated'             => '새 백업 파일이 생성되었습니다.',
        'file_not_found'        => '지정한 백업 파일을 서버에서 찾을 수 없습니다.',
        'restore_warning'       => 'Yes, restore it. I acknowledge that this will overwrite any existing data currently in the database. This will also log out all of your existing users (including you).',
        'restore_confirm'       => 'Are you sure you wish to restore your database from :filename?'
    ],
    'purge' => [
        'error'     => '삭제중 오류가 발생하였습니다. ',
        'validation_failed'     => '삭제 확인 절차가 잘못되었습니다. 확인 상자에 "DELETE"를 입력해 주세요.',
        'success'               => '삭제된 기록들이 삭제되었습니다.',
    ],
    'mail' => [
        'sending' => 'Sending Test Email...',
        'success' => 'Mail sent!',
        'error' => 'Mail could not be sent.',
        'additional' => 'No additional error message provided. Check your mail settings and your app log.'
    ],
    'ldap' => [
        'testing' => 'Testing LDAP Connection, Binding & Query ...',
        '500' => '500 Server Error. Please check your server logs for more information.',
        'error' => 'Something went wrong :(',
        'sync_success' => 'A sample of 10 users returned from the LDAP server based on your settings:',
        'testing_authentication' => 'Testing LDAP Authentication...',
        'authentication_success' => 'User authenticated against LDAP successfully!'
    ],
    'webhook' => [
        'sending' => 'Sending :app test message...',
        'success' => 'Your :webhook_name Integration works!',
        'success_pt1' => 'Success! Check the ',
        'success_pt2' => ' channel for your test message, and be sure to click SAVE below to store your settings.',
        '500' => '500 Server Error.',
        'error' => 'Something went wrong. :app responded with: :error_message',
        'error_redirect' => 'ERROR: 301/302 :endpoint returns a redirect. For security reasons, we don’t follow redirects. Please use the actual endpoint.',
        'error_misc' => 'Something went wrong. :( ',
    ]
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ko-KR/admin/settings/message.php <==
<?php

return [

    'update' => [
        'error'                 => '갱신 중 오류가 발생했습니다. ',
        'success'               => '설정이 갱신되었습니다.',
    ],
    'backup' => [
        'delete_confirm'        => '이 백업 파일을 지우시겠습니까? 이 동작은 되돌리기가 되지 않습니다. ',
        'file_deleted'          => '백업 파일이 삭제 되었습니다. ',
        'generated'             => '새 백업 파일이 생성되었습니다.',
        'file_not_found'        => '지정한 백업 파일을 서버에서 찾을 수 없습니다.',
        'restore_warning'       => 'Yes, restore it. I acknowledge that this will overwrite any existing data currently in the database. This will also log out all of your existing users (including you).',
        'restore_confirm'       => 'Are you sure you wish to restore your database from :filename?'
    ],
    'restore' => [
        'success'               => 'Your system backup has been restored. Please log in again.'
    ],
    'purge' => [
        'error'     => '삭제중 오류가 발생하였습니다. ',
        'validation_failed'     => '삭제 확인 절차가 잘못되었습니다. 확인 상자에 "DELETE"를 입력해 주세요.',
        'success'               => '삭제된 기록들이 삭제되었습니다.',
    ],
    'mail' => [
        'sending' => 'Sending Test Email...',
        'success' => 'Mail sent!',
        'error' => 'Mail could not be sent.',
        'additional' => 'No additional error message provided. Check your mail settings and your app log.'
    ],
    'ldap' => [
        'testing' => 'Testing LDAP Connection, Binding & Query ...',
        '500' => '500 Server Error. Please check your server logs for more information.',
        'error' => 'Something went wrong :(',
        'sync_success' => 'A sample of 10 users returned from the LDAP server based on your settings:',
        'testing_authentication' => 'Testing LDAP Authentication...',
        'authentication_success' => 'User authenticated against LDAP successfully!'
    ],
    'webhook' => [
        'sending' => 'Sending :app test message...',
        'success' => 'Your :webhook_name Integration works!',
        'success_pt1' => 'Success! Check the ',
        'success_pt2' => ' channel for your test message, and be sure to click SAVE below to store your settings.',
        '500' => '500 Server Error.',
        'error' => 'Something went wrong. :app responded with: :error_message',
        'error_redirect' => 'ERROR: 301/302 :endpoint returns a redirect. For security reasons, we don’t follow redirects. Please use the actual endpoint.',
        'error_misc' => 'Something went wrong. :( ',
        'webhook_fail' => ' webhook notification failed: Check to make sure the URL is still valid.',
    ]
];
